import { ICompletionResponse } from './protocol';
/**
 * Responsible for fetching completions from a model and adding them to the input.
 * Each `<SmartInput />` component rendered to the DOM will have its own instance of this class as state.
 */
export declare class SmartInputFetcher {
    private apiUrl;
    addCompletion: (text: string, completion: ICompletionResponse) => void;
    modelId?: string | undefined;
    mockCompletion?: ((text: string) => string | null) | undefined;
    /**
     * sequenceId is used to ensure that we don't add completions from a previous fetch,
     * we increment it each time we request to fetch a new completion because the user input has changed
     */
    sequenceId: number;
    /**
     * sessionId is used to track this particular instantiation of the `<SmartInput />` component
     */
    sessionId: string;
    /**
     * completionCache is used to cache the completions that we've already fetched from the model
     */
    completionCache: Record<string, ICompletionResponse | null>;
    /**
     * alreadySeen tracks which completions we've marked as seen (reduce chattiness)
     */
    alreadySeen: Set<string>;
    /**
     * alreadyAccepted tracks which completions we've marked as acceoted (reduce chattiness)
     */
    alreadyAccepted: Set<string>;
    /**
     * currentCompletion tracks the latest text that was sent to the model for fetching completions, and the
     * completion that was returned (if any ~ we may still be waiting for it)
     */
    currentCompletion: {
        sequenceId: number;
        text: string;
        completion?: string | null;
    } | null;
    constructor(apiUrl: string, addCompletion: (text: string, completion: ICompletionResponse) => void, modelId?: string | undefined, mockCompletion?: ((text: string) => string | null) | undefined);
    fetchCompletion: import("./util/debounce").DebouncedFunction<any[], (text: string, context: any) => Promise<ICompletionResponse | null>>;
    updateCompletion(completionSid: string, arg: {
        seen?: boolean;
        accepted?: boolean;
    }): void;
    sendEvents: (text: string, context: any) => void;
}
